package com.zayac.admin.system.model.req;

import java.io.Serial;
import java.time.LocalDateTime;

import jakarta.validation.constraints.*;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import org.hibernate.validator.constraints.Length;

import top.continew.starter.extension.crud.model.req.BaseReq;

/**
 * 创建或修改账号信息
 *
 * @author zayac
 * @since 2024/05/10 20:44
 */
@Data
@Schema(description = "创建或修改账号信息")
public class AccountReq extends BaseReq {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 账号昵称
     */
    @Schema(description = "账号昵称")
    @Length(max = 60, message = "账号昵称长度不能超过 {max} 个字符")
    private String name;

    /**
     * 账号
     */
    @Schema(description = "账号")
    @NotBlank(message = "账号不能为空")
    @Length(max = 20, message = "账号长度不能超过 {max} 个字符")
    private String username;

    /**
     * 账号类型(0:开云,1:华体会,2:九游,3:爱游戏)
     */
    @Schema(description = "账号类型(0:开云,1:华体会,2:九游,3:爱游戏)")
    @NotNull(message = "账号类型(0:开云,1:华体会,2:九游,3:爱游戏)不能为空")
    private Boolean type;

    /**
     * 状态（1：启用；2：禁用)
     */
    @Schema(description = "状态（1：启用；2：禁用)")
    @NotNull(message = "状态（1：启用；2：禁用)不能为空")
    private Integer status;

    /**
     * 对应平台的url
     */
    @Schema(description = "对应平台的url")
    @Length(max = 100, message = "对应平台的url长度不能超过 {max} 个字符")
    private String url;
}