package com.zayac.admin.system.model.resp;

import java.io.Serial;
import java.time.LocalDateTime;

import com.zayac.admin.common.enums.DisEnableStatusEnum;
import com.zayac.admin.system.enums.AccountTypeEnum;
import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import top.continew.starter.extension.crud.model.resp.BaseResp;

/**
 * 账号信息
 *
 * @author zayac
 * @since 2024/05/10 20:44
 */
@Data
@Schema(description = "账号信息")
public class AccountResp extends BaseResp {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 账号昵称
     */
    @Schema(description = "账号昵称", example = "ky1线")
    private String nickname;

    /**
     * 账号
     */
    @Schema(description = "账号", example = "ky3tg107001")
    private String username;

    /**
     * 平台(0:开云,1:华体会,2:九游,3:爱游戏)
     */
    @Schema(description = "平台(0:开云,1:华体会,2:九游,3:爱游戏)", type = "Integer", allowableValues = {"0", "1", "2", "3", "4"}, example = "1")
    private AccountTypeEnum type;

    /**
     * headers
     */
    @Schema(description = "headers",type = "JSON")
    private String headers;

    /**
     * 状态（1：启用；2：禁用)
     */
    @Schema(description = "状态（1：启用；2：禁用)")
    private DisEnableStatusEnum status;

    /**
     * 对应平台的url
     */
    @Schema(description = "平台地址")
    private String url;


    /**
     * 用户ID
     */
    @Schema(description = "用户ID")
    private Long userId;
}